@@ -20,7 +20,7 @@ from . import parse
 from .utils import (meshgrid, slice_syntax, _is_query,
                     _new_attribute_label, as_list)
 from ._py3k_compat import genfromstr, iteritems, csv_reader, string_type, dtype as _dtype
-from .schema_utils import change_axis_schema, dimension_rename, new_alias_label
+from .schema_utils import change_axis_schema, attribute_rename, dimension_rename, new_alias_label
 from . import schema_utils as su
 from .robust import (join, cumulate, reshape, thin, cross_join)
 
@@ -166,7 +166,7 @@ class sdbtype(object):
     @classmethod
     def from_full_rep(cls, rep):
         schema = '<%s>' % (','.join('%s: %s %s' %
-                                    (nm, typ, 'NULL' if null else '')
+                                    (nm, typ, '' if null else 'NOT NULL')
                                     for nm, typ, null in rep))
         return cls(schema)
 
@@ -195,7 +195,7 @@ class sdbtype(object):
 
         names = [str(s[0]) for s in sdbL]
         dtypes = [s[1].split()[0] for s in sdbL]
-        nullable = ['null' in (''.join(s[1].split()[1:])).lower()
+        nullable = ['not null' not in (' '.join(s[1].split()[1:])).lower()
                     for s in sdbL]
         return list(zip(names, dtypes, nullable))
 
@@ -222,7 +222,7 @@ class sdbtype(object):
 
     @classmethod
     def _dtype_to_schema(cls, dtype):
-        """Convert a scidb type schema to a numpy dtype
+        """Convert a numpy dtype schema to a scidb type
 
         Parameters
         ----------
@@ -239,7 +239,7 @@ class sdbtype(object):
         # Hack: if we re-encode this as a dtype, then de-encode again, numpy
         #       will add default names where they are missing
         dtype = _dtype(dtype).descr
-        pairs = ["{0}:{1}".format(d[0], _sdb_type(d[1])) for d in dtype]
+        pairs = ["{0}:{1} NOT NULL".format(d[0], _sdb_type(d[1])) for d in dtype]
         return '<{0}>'.format(','.join(pairs))
 
 
@@ -356,22 +356,22 @@ class SciDBDataShape(object):
         This function uses a series of regular expressions to take an input
         schema such as::
 
-            schema = "not empty myarray<val:double> [i0=0:3,4,0,i1=0:4,5,0]"
+            schema = "not empty myarray<val:double> [i0=0:3:0:4;i1=0:4:0:5]"
 
         parse it, and return a SciDBDataShape object.
         """
         # First split out the array name, data types, and shapes.  e.g.
         #
-        #   "myarray<val:double,rank:int32> [i=0:4,5,0,j=0:9,5,0]"
+        #   "myarray<val:double,rank:int32> [i=0:4:0:5;j=0:9:0:5]"
         #
         # will become
         #
         #   dict(arrname = "myarray"
         #        dtypes  = "val:double,rank:int32"
-        #        dshapes = "i=0:9,5,0,j=0:9,5,0")
+        #        dshapes = "i=0:9:0:5;j=0:9:0:5")
         #
         R = re.compile(r'(?P<arrname>[\s\S]+)\<(?P<schema>[\S\s]*?)\>(?:\s*)'
-                       '\[(?P<dshapes>\S+)\]')
+                       '\[(?P<dshapes>[\s\S]+)\]')
         schema = schema.lstrip('schema').strip()
         match = R.search(schema)
         try:
@@ -383,14 +383,14 @@ class SciDBDataShape(object):
             raise ValueError("no match for schema: {0}".format(schema))
 
         # split dshapes.  TODO: correctly handle '*' dimensions
-        R = re.compile(r'(\S*?)=(\S*?):([\S\*]*?),(\S*?),(\S*?),')
-        dshapes = R.findall(dshapes + ',')  # note added trailing comma
+        R = re.compile(r'(\S*?)=(\S*?):([\S\*]*?):(\S*?):(\S*?);')
+        dshapes = R.findall(dshapes + ';')  # note added trailing comma
 
         return cls(None,
                    typecode=schema,
                    dim_names=[d[0] for d in dshapes],
-                   chunk_size=[int(d[3]) for d in dshapes],
-                   chunk_overlap=[int(d[4]) for d in dshapes],
+                   chunk_overlap=[int(d[3]) for d in dshapes],
+                   chunk_size=[int(d[4]) for d in dshapes],
                    dim_low=[d[1] for d in dshapes],
                    dim_high=[d[2] for d in dshapes])
 
@@ -428,14 +428,14 @@ class SciDBDataShape(object):
         """
         The dimension part of the schema
         """
-        result = ','.join(['{0}={1}:{2},{3},{4}'.format(d, l,
+        result = ';'.join(['{0}={1}:{2}:{3}:{4}'.format(d, l,
                                                         h if h is not None else '*',
-                                                        cs, co)
-                           for (d, l, h, cs, co) in zip(self.dim_names,
+                                                        co, cs)
+                           for (d, l, h, co, cs) in zip(self.dim_names,
                                                         self.dim_low,
                                                         self.dim_high,
-                                                        self.chunk_size,
-                                                        self.chunk_overlap)])
+                                                        self.chunk_overlap,
+                                                        self.chunk_size)])
         return '[%s]' % result
 
     @property
@@ -613,6 +613,8 @@ class SciDBArray(object):
         self : SciDBArray
             return a pointer to self
         """
+        self.eval()  # SciDB rename doesn't work on queries, only arrays
+
         new_name = str(new_name)
 
         if new_name in self.interface.list_arrays():
@@ -768,7 +770,7 @@ class SciDBArray(object):
 
     def __repr__(self):
         show = self.interface._show_array(self.name, fmt='csv').split('\n')
-        return "SciDBArray({0})".format(show[1])
+        return "SciDBArray({0})".format(show[0])
 
     def contents(self, **kwargs):
         """
@@ -994,7 +996,6 @@ class SciDBArray(object):
                                              "and will be removed in a future version"))
             kwargs.pop('transfer_bytes')
 
-        self.eval()  # evaluate if needed, for speed
         return parse.toarray(self, **kwargs)
 
     def eval(self, out=None, store=True, **kwargs):
@@ -1091,6 +1092,28 @@ class SciDBArray(object):
         """
         return self.toarray(**kwargs).tolist()
 
+    def as_temp(self, name=None):
+        """
+        Create a SciDB TEMP array, stored in RAM
+
+        Returns
+        -------
+        temp : SciDBArray
+            A new array, stored in-memory in the database
+        """
+        self.eval()
+
+        if not name:
+            name = self.interface._db_array_name()
+
+        schema = self.schema
+
+        self.afl.create_array(name, schema, True).eval(store=False)
+        result = self.interface.wrap_array(name, persistent=False)
+        self.store(result).eval(store=False)
+
+        return result
+
     def _integer_index(self, idx):
         """
         Index using an integer array
@@ -1329,7 +1352,7 @@ class SciDBArray(object):
 
         if len(args) == 0:
             return self
-        return self.afl.attribute_rename(self, *args)
+        return attribute_rename(self, *args)
 
     def relabel(self, renames):
         """
