@@ -29,32 +29,32 @@ class TestBasicUse(TestBase):
 
     def test_query(self):
         ARR = sdb.ones((4))
-        assert afl.normalize(ARR).query == "normalize(%s)" % ARR.name
+        assert afl.transpose(ARR).query == "transpose(%s)" % ARR.name
 
     def test_result(self):
-        ARR = sdb.ones((4))
-        s = afl.normalize(ARR)
-        expected = np.ones(4) / 2
+        ARR = sdb.random((4))
+        s = afl.sort(ARR)
+        expected = np.sort(ARR.toarray()) 
         np.testing.assert_array_almost_equal(s.toarray(), expected)
 
     def test_results_cached(self):
         ARR = sdb.ones((4))
-        s = afl.normalize(ARR)
+        s = afl.transpose(ARR)
         s.eval() is s.eval()
 
     def test_eval_nostore(self):
         ARR = sdb.ones((4))
-        s = afl.normalize(ARR)
+        s = afl.transpose(ARR)
         s.eval(store=False)
         assert s.name not in sdb.list_arrays()
 
     def test_eval_output(self):
-        ARR = sdb.ones((4))
-        s = afl.normalize(ARR)
+        ARR = sdb.random((4))
+        s = afl.sort(ARR)
         out = sdb.new_array()
         result = s.eval(out=out)
         assert result.name is out.name
-        expected = np.ones(4) / 2
+        expected = np.sort(ARR.toarray()) 
         np.testing.assert_array_almost_equal(s.toarray(), expected)
 
     def test_access_from_interface(self):
@@ -62,7 +62,7 @@ class TestBasicUse(TestBase):
 
     def test_interface_access_cached(self):
         assert sdb.afl is sdb.afl
-        assert sdb.afl.normalize is sdb.afl.normalize
+        assert sdb.afl.transpose is sdb.afl.transpose
 
     def test_operator_chaining_syntax(self):
         a = afl
@@ -84,11 +84,11 @@ class TestFormatOperands(TestBase):
 
     def test_expression_given_by_query(self):
         ARR = sdb.ones((4))
-        assert _format_operand(afl.normalize(ARR)) == "normalize(%s)" % ARR.name
+        assert _format_operand(afl.transpose(ARR)) == "transpose(%s)" % ARR.name
 
     def test_expression_given_by_result_name_if_evaluated(self):
         ARR = sdb.ones((4))
 
-        exp = afl.normalize(ARR)
+        exp = afl.transpose(ARR)
         exp.eval()
         assert _format_operand(exp) == exp.eval().name
