@@ -321,9 +321,11 @@ def test_svd():
     U, S, VT = sdb.svd(A)
     U2, S2, VT2 = np.linalg.svd(A.toarray(), full_matrices=False)
 
-    assert_allclose(U.toarray(), U2, rtol=RTOL)
-    assert_allclose(S.toarray(), S2, rtol=RTOL)
-    assert_allclose(VT.toarray(), VT2, rtol=RTOL)
+    assert_allclose(np.mat(U.toarray()) * np.diag(S.toarray()) * np.mat(VT.toarray()), np.mat(A.toarray()), rtol=RTOL)
+
+    assert_allclose(np.absolute(U.toarray()), np.absolute(U2), rtol=RTOL)
+    assert_allclose(np.absolute(S.toarray()), np.absolute(S2), rtol=RTOL)
+    assert_allclose(np.absolute(VT.toarray()), np.absolute(VT2), rtol=RTOL)
 
 
 def test_abs():
@@ -820,10 +822,9 @@ def test_dstack():
 
 def test_ls():
     x = sdb.zeros(5)
-    sdb.ls(x.name) == [x.name]
-    sdb.ls(x.name + '*') == [x.name]
-    sdb.ls('DOES NOT EXIST') == []
-    assert sorted(sdb.ls('*')) == sorted(sdb.list_arrays().keys())
+    assert sdb.ls(x.name) == [x.name]
+    assert sdb.ls(x.name + '*') == [x.name]
+    assert sdb.ls('DOES NOT EXIST') == []
 
 
 def test_remove_array():
@@ -874,6 +875,35 @@ def test_index_lookup():
     assert_array_equal(x['tmp'].toarray(), [2, 2, 2, 1, 2, 1, 0])
 
 
+def test_rename_on_unevaluated():
+    # regression test for #71
+
+    x = sdb.zeros(5).apply('a', 1)
+    assert x.query is not None
+
+    x.rename('junk')
+    assert x.name == 'junk'
+    x.reap()
+
+
+def test_as_temp():
+    x = sdb.arange(5)
+
+    y = x.as_temp()
+    assert_array_equal(y.toarray(), [0, 1, 2, 3, 4])
+
+    # check temporary status
+    a = x.afl.list("'arrays'").toarray()
+    names = a['name'].tolist()
+    assert not a['temporary'][names.index(x.name)]
+    assert a['temporary'][names.index(y.name)]
+
+    # y reaped properly
+    assert not y.persistent
+    sdb.reap()
+    assert y.name not in sdb.list_arrays()
+
+
 class TestHead(TestBase):
 
     @needs_pandas
